
import { MainPage } from 'apps/admin-e2e/src/page-objects/main.po';
import { BenutzerE2EComponent } from '../../../components/benutzer/benutzer.e2e.component';
import { beChecked, beEnabled, contains, exist, notBeChecked, notBeEnabled } from '../../../support/cypress.util';
import { AlfaRollen, AlfaUsers, loginAsAriane } from '../../../support/user-util';
import { SnackBarE2EComponent } from '../../../components/ui/snackbar.e2e.component';
import { SnackbarMessagesE2E } from '../../../model/util';
import { wait, waitOfInterceptor } from 'apps/admin-e2e/src/support/cypress-helper';

const mainPage: MainPage = new MainPage();
const benutzerPage: BenutzerE2EComponent = new BenutzerE2EComponent();
const snackBar: SnackBarE2EComponent = new SnackBarE2EComponent();

const vorname: string = 'Theo';
const nachname: string = 'Testuser';
const benutzername: string = 'testtheo';
const emailAddress: string = 'theo.test@ozg-sh.de';

describe('Benutzer anlegen', () => {
  before(() => {
    loginAsAriane();
  });

  it('should open Benutzer tab and show Hinzufuegen button', () => {
    mainPage.clickBenutzerTab();

    exist(benutzerPage.getHinzufuegenButton());
  });

  it.skip('should not do anything after click on save with missing data', () => {
    benutzerPage.addUser();
    benutzerPage.saveUser();
    
    //TODO: Fehlermeldungen hinzufügen
  });

  it('should show snackbar message on error', () => {
    const interceptor: string = 'postUser';
    const url: string = 'https://sso.dev.by.ozg-cloud.de/admin/realms/by-e2e-tests-local-dev/users'
    const errorCode: number = 500;
    const errorBody: string = 'Internal Server Error';

    cy.intercept('POST', url, {statusCode: errorCode, body: errorBody}).as(interceptor);

    benutzerPage.addUser();
    benutzerPage.saveUser();

    waitOfInterceptor(interceptor).then(() => {
      contains(snackBar.getMessage(), SnackbarMessagesE2E.NUTZER_FEHLGESCHLAGEN);
    });
  });

  it('should show snackbar message on saving user', () => {
    snackBar.getCloseButton().click();
  
    benutzerPage.enterVorname(vorname);
    benutzerPage.enterNachname(nachname);
    benutzerPage.enterBenutzername(benutzername);
    benutzerPage.enterMail(emailAddress);
    benutzerPage.clickAdminCheckbox();
    benutzerPage.clickUserCheckbox();

    benutzerPage.saveUser();
    contains(snackBar.getMessage(), SnackbarMessagesE2E.NUTZER_ANGELEGT);
  });

  it('should display new user in users table', () => {
    benutzerPage.stringExistsInUserEntry(AlfaRollen.USER, benutzername);
    benutzerPage.stringExistsInUserEntry(vorname, benutzername);
    benutzerPage.stringExistsInUserEntry(nachname, benutzername);
    // FEHLT NOCH: benutzerPage.stringExistsInUserEntry(AlfaRollen.ADMIN, benutzername);
  });
});
