/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BuildInfoE2EComponent } from '../components/buildinfo/buildinfo.e2e.component';
import { containClass } from '../support/cypress.util';
import { HeaderE2EComponent } from './header.po';

export class MainPage {
  private readonly buildInfo: BuildInfoE2EComponent = new BuildInfoE2EComponent();
  private readonly header: HeaderE2EComponent = new HeaderE2EComponent();

  private readonly benutzerTab: string = 'caption-Benutzer__Rollen';
  private readonly postfachTab: string = 'caption-Postfach';
  private readonly organisationsEinheitenTab: string = 'caption-Organisationseinheiten';

  private readonly postfachNavigationItem: string = 'postfach-navigation';
  private readonly organisationEinheitNavigation: string = 'organisations-einheiten-navigation';
  private readonly statistikNavigationItem: string = 'statistik-navigation';

  public getBuildInfo(): BuildInfoE2EComponent {
    return this.buildInfo;
  }

  public getHeader(): HeaderE2EComponent {
    return this.header;
  }

  public getBenutzerTab(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.benutzerTab);
  }

  public clickBenutzerTab(): void {
    this.getBenutzerTab().click();
  }

  public getPostfachNavigationItem(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.postfachNavigationItem);
  }

  public getOrganisationEinheitNavigationItem(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.organisationEinheitNavigation);
  }

  public getOrganisationsEinheitenMenu(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.organisationsEinheitenTab);
  }

  public openOrganisationsEinheiten(): void {
    this.getOrganisationsEinheitenMenu().click();
  }

  public getStatistikNavigationItem(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.statistikNavigationItem);
  }

  public isStatistikNavigationItemSelected(): void {
    containClass(this.getStatistikNavigationItem().get('a'), 'border-selected');
  }

  public openStatistik(): void {
    this.getStatistikNavigationItem().click();
  }
}

export function waitForSpinnerToDisappear(): boolean {
  return cy.getTestElementWithClass('spinner').should('not.exist');
}

export function waitforSpinnerToAppear(): void {
  // exist(cy.getTestElementWithClass('spinner'));
}
