/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { containClass, mouseEnter, notContainClass } from './cypress.util';

export const TOGGLE_ELEMENT: string = 'mat-slide-toggle';

enum AngularClassesE2E {
  MAT_CHECKED = 'mat-mdc-slide-toggle-checked',
  ODS_BUTTON_TOGGLE_CHECKED = 'ods-button-toggle-checked',
  MAT_FOCUSED = 'mat-focused',
  CDK_KEYBOARD_FOCUSED = 'cdk-keyboard-focused',
  MAT_BADGE_HIDDEN = 'mat-badge-hidden',
}

enum AngularElementE2E {
  MAT_FORM_FIELD = 'mat-form-field',
}

export function hasTooltip(element: any, value: string) {
  mouseEnter(element);
  element.get('ods-tooltip').contains(value);
}

export function isChecked(element: any) {
  containClass(element, AngularClassesE2E.MAT_CHECKED);
}

export function isNotChecked(element: any) {
  notContainClass(element, AngularClassesE2E.MAT_CHECKED);
}

export function isOdsButtonToggleChecked(element: any) {
  containClass(element, AngularClassesE2E.ODS_BUTTON_TOGGLE_CHECKED);
}

export function isOdsButtonToggleNotChecked(element: any) {
  notContainClass(element, AngularClassesE2E.ODS_BUTTON_TOGGLE_CHECKED);
}

export function getFormField(element: any) {
  return element.find(AngularElementE2E.MAT_FORM_FIELD);
}

export function isMatFocused(element: any) {
  containClass(element, AngularClassesE2E.MAT_FOCUSED);
}

export function isKeyboardFocused(element: any) {
  containClass(element, AngularClassesE2E.CDK_KEYBOARD_FOCUSED);
}

export function expectIconWithoutBadge(element: any): void {
  containClass(element, AngularClassesE2E.MAT_BADGE_HIDDEN);
}

export function expectIconWithBadge(element: any): void {
  notContainClass(element, AngularClassesE2E.MAT_BADGE_HIDDEN);
}
