/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { contains, enterWith, haveValue } from '../../support/cypress.util';

export class VorgangZusammenarbeitE2EComponent {
  private readonly anfrageButton: string = 'anfrage-erstellen-button';
  private readonly zustaendigeStelleButton: string = 'organisations-einheit-search-button';
  private readonly titelText: string = 'Titel-text-input';
  private readonly messageText: string = 'Beschreibung-textarea';
  private readonly sendButton: string = 'collaboration-request-submit-button';
  private readonly cancelButton: string = 'collaboration-request-cancel-button';
  private readonly searchText: string = 'instant_search-text-input';
  private readonly closeSearchButton: string = 'close-search-dialog';
  private readonly clearSearchButton: string = 'clear-instant-search';
  private readonly searchEntry: string = 'item-button';
  private readonly orgaAddress: string = 'organisations-einheit-in-collaboration';
  private readonly anfrageResult: string = 'collaboration-request-result';

  public getAnfrageButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.anfrageButton);
  }

  public createAnfrage(stelle: number): void {
    this.getAnfrageButton().eq(stelle).click();
  }

  public getZustaendigeStelleButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.zustaendigeStelleButton);
  }

  public searchZustaendigeStelle(): void {
    this.getZustaendigeStelleButton().click();
  }

  public getStelleTitel(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.titelText);
  }

  public enterTitel(text: string): void {
    enterWith(this.getStelleTitel(), text);
  }

  public getMessageText(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.messageText);
  }

  public enterMessage(text: string): void {
    enterWith(this.getMessageText(), text);
  }

  public messageScrollbarIsPresent(): void {
    this.getMessageText().then(($textarea) => {
      const scrollHeight = $textarea[0].scrollHeight;
      const clientHeight = $textarea[0].clientHeight;

      expect(scrollHeight).to.be.greaterThan(clientHeight);
    });
  }

  public getSendButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.sendButton);
  }

  public sendAnfrage(): void {
    this.getSendButton().click();
  }

  public getCancelButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.cancelButton);
  }

  public cancelAnfrage(): void {
    this.getCancelButton().click();
  }

  public getCloseSearchButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.closeSearchButton);
  }

  public closeSearch(): void {
    this.getCloseSearchButton().click();
  }

  public getSearchText(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.searchText);
  }

  public hasSearchText(text: string): void {
    haveValue(this.getSearchText(), text);
  }

  public enterSearchInput(text: string): void {
    this.getSearchText().clear().type(text);
  }

  public getClearSearchButton(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.clearSearchButton);
  }

  public clearSearch(): void {
    this.getClearSearchButton().click();
  }

  public countSearchEntries(): Cypress.Chainable<number> {
    return cy.getTestElement(this.searchEntry).then((entries) => {
      return Cypress.$(entries).length;
    });
  }

  public expectNumberOfEntriesToBe(entries: number): void {
    this.countSearchEntries().then((count) => {
      expect(count).to.equal(entries);
    });
  }

  public expectNumberOfEntriesToBeGreaterThan(entries: number): void {
    this.countSearchEntries().then((count) => {
      expect(count).to.greaterThan(entries);
    });
  }

  public clickSearchEntry(index: number): void {
    cy.getTestElement(this.searchEntry).eq(index).click();
  }

  public addressContains(address: string): void {
    contains(cy.getTestElement(this.orgaAddress), address);
  }

  public getAnfrageResult(): Cypress.Chainable<JQuery<HTMLElement>> {
    return cy.getTestElement(this.anfrageResult);
  }

  public anfrageResultContains(anfrage: string): void {
    contains(this.getAnfrageResult(), anfrage);
  }
}
