/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ConfigurationResource } from '@admin-client/configuration-shared';
import { ApiRootLinkRel, ApiRootResource, ApiRootService } from '@alfa-client/api-root-shared';
import { ListResourceServiceConfig, ResourceListService, ResourceRepository } from '@alfa-client/tech-shared';
import { OrganisationsEinheitListLinkRel } from './organisations-einheit.linkrel';
import { AdminOrganisationsEinheitItemResource, AdminOrganisationsEinheitListResource } from './organisations-einheit.model';

export class OrganisationsEinheitListResourceService extends ResourceListService<
  ApiRootResource,
  AdminOrganisationsEinheitListResource,
  AdminOrganisationsEinheitItemResource
> {}

export function createOrganisationsEinheitListResourceService(repository: ResourceRepository, apiRootService: ApiRootService) {
  return new ResourceListService(buildConfig(apiRootService), repository);
}

function buildConfig(apiRootService: ApiRootService): ListResourceServiceConfig<ConfigurationResource> {
  return {
    baseResource: apiRootService.getApiRoot(),
    createLinkRel: 'TODO',
    listLinkRel: ApiRootLinkRel.ORGANISATIONS_EINHEIT,
    listResourceListLinkRel: OrganisationsEinheitListLinkRel.LIST,
  };
}
