/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ConfigurationResource } from '@admin-client/configuration-shared';
import { ApiResourceService, ResourceRepository, ResourceServiceConfig } from '@alfa-client/tech-shared';
import { OrganisationsEinheitListResourceService } from './organisations-einheit-list-resource.service';
import { OrganisationsEinheitLinkRel } from './organisations-einheit.linkrel';
import { AdminOrganisationsEinheitResource } from './organisations-einheit.model';

export class OrganisationsEinheitResourceService extends ApiResourceService<
  AdminOrganisationsEinheitResource,
  AdminOrganisationsEinheitResource
> {}

export function createOrganisationsEinheitResourceService(
  repository: ResourceRepository,
  listResourceService: OrganisationsEinheitListResourceService,
) {
  return new ApiResourceService(buildConfig(listResourceService), repository);
}

function buildConfig(listResourceService: OrganisationsEinheitListResourceService): ResourceServiceConfig<ConfigurationResource> {
  return {
    resource: listResourceService.getSelected(),
    getLinkRel: OrganisationsEinheitLinkRel.SELF,
    edit: { linkRel: OrganisationsEinheitLinkRel.SELF },
  };
}
