/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { faker } from '@faker-js/faker';
import { toResource } from 'libs/tech-shared/test/resource';
import { times } from 'lodash-es';
import { OrganisationsEinheitListLinkRel } from '../lib/organisations-einheit.linkrel';
import {
  AdminOrganisationsEinheit,
  AdminOrganisationsEinheitListResource,
  AdminOrganisationsEinheitResource,
  AdminOrganisationsEinheitSyncResult,
} from '../lib/organisations-einheit.model';

export function createAdminOrganisationsEinheit(): AdminOrganisationsEinheit {
  return {
    name: faker.lorem.word(),
    organisationsEinheitId: faker.lorem.word(),
    syncResult: AdminOrganisationsEinheitSyncResult.OK,
    settings: {
      signatur: faker.lorem.words(5),
    },
  };
}

export function createAdminOrganisationsEinheitResource(linkRel: string[] = []): AdminOrganisationsEinheitResource {
  return toResource(createAdminOrganisationsEinheit(), linkRel);
}

export function createAdminOrganisationsEinheitResources(linkRelations: string[] = []): AdminOrganisationsEinheitResource[] {
  return times(10, () => toResource(createAdminOrganisationsEinheit(), [...linkRelations]));
}

export function createAdminOrganisationsEinheitListResource(
  resources?: AdminOrganisationsEinheitResource[],
  linkRelations: string[] = [],
): AdminOrganisationsEinheitListResource {
  return toResource({}, [...linkRelations], {
    [OrganisationsEinheitListLinkRel.LIST]: resources ? resources : createAdminOrganisationsEinheitResources(),
  });
}
