/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { NavigationSharedModule } from '@alfa-client/navigation-shared';
import { getElementFromFixture, mock, useFromMock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { EffectsModule } from '@ngrx/effects';
import { StoreModule } from '@ngrx/store';
import { TextareaEditorComponent } from '@ods/component';
import { OrganisationsEinheitService } from 'libs/admin/organisations-einheit-shared/src';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent, MockModule } from 'ng-mocks';
import { OrganisationsEinheitFormService } from '../organisations-einheit.formservice';
import { OrganisationsEinheitSignaturComponent } from './organisations-einheit-signatur.component';

describe('OrganisationsEinheitSignaturComponent', () => {
  let component: OrganisationsEinheitSignaturComponent;
  let fixture: ComponentFixture<OrganisationsEinheitSignaturComponent>;
  let formService: OrganisationsEinheitFormService;

  const signaturTextareaSelector: string = getDataTestIdOf('signatur-text');

  beforeEach(async () => {
    formService = new OrganisationsEinheitFormService(new FormBuilder(), useFromMock(mock(OrganisationsEinheitService)));

    await TestBed.configureTestingModule({
      imports: [
        OrganisationsEinheitSignaturComponent,
        StoreModule.forRoot({}),
        EffectsModule.forRoot([]),
        MockModule(ReactiveFormsModule),
        MockModule(NavigationSharedModule),
        MockComponent(TextareaEditorComponent),
      ],
      providers: [
        {
          provide: OrganisationsEinheitFormService,
          useValue: formService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(OrganisationsEinheitSignaturComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('ods-textarea-editor', () => {
      describe('input', () => {
        it('should set signatur field', () => {
          const textAreaEditor: HTMLElement = getElementFromFixture(fixture, signaturTextareaSelector);

          expect(textAreaEditor.getAttribute('rows')).toEqual('6');
        });
      });
    });
  });
});
