/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { StateResource, createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { FormBuilder } from '@angular/forms';
import { OrganisationsEinheitService } from 'libs/admin/organisations-einheit-shared/src';
import { AdminOrganisationsEinheitResource } from 'libs/admin/organisations-einheit-shared/src/lib/organisations-einheit.model';
import { createAdminOrganisationsEinheitResource } from 'libs/admin/organisations-einheit-shared/src/test/organisations-einheit';
import { of } from 'rxjs';
import { OrganisationsEinheitFormService } from './organisations-einheit.formservice';

describe('OrganisationsEinheitFormService', () => {
  let service: OrganisationsEinheitFormService;
  let organisationsEinheitService: Mock<OrganisationsEinheitService>;
  const formBuilder: FormBuilder = new FormBuilder();

  beforeEach(() => {
    organisationsEinheitService = mock(OrganisationsEinheitService);
    service = new OrganisationsEinheitFormService(formBuilder, useFromMock(organisationsEinheitService));
  });

  it('should create', () => {
    expect(service).toBeTruthy();
  });

  describe('submit', () => {
    const organisationsEinheitResource: AdminOrganisationsEinheitResource = createAdminOrganisationsEinheitResource();

    beforeEach(() => {
      const stateResource: StateResource<AdminOrganisationsEinheitResource> = createStateResource(organisationsEinheitResource);
      organisationsEinheitService.patch.mockReturnValue(of(stateResource));
      organisationsEinheitService.get.mockReturnValue(of(stateResource));
      service.form.setValue({
        [OrganisationsEinheitFormService.ORGANISATIONSEINHEIT_SIGNATUR_FIELD]: organisationsEinheitResource.settings.signatur,
      });
    });

    it('should call organisationsEinheitService patch', () => {
      service.submit();

      expect(organisationsEinheitService.patch).toHaveBeenCalledWith(organisationsEinheitResource.settings);
    });
  });
});
