/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { faker } from '@faker-js/faker';
import { SettingItemResource, SettingName } from 'libs/admin/settings-shared/src/lib/settings.model';
import { toResource } from 'libs/tech-shared/test/resource';
import { Postfach, PostfachResource, PostfachSettingsItem } from '../lib/postfach.model';

export function createPostfach(): Postfach {
  return {
    absender: {
      name: faker.person.lastName(),
      anschrift: faker.internet.email(),
      dienst: faker.person.jobTitle(),
      mandant: faker.person.jobArea(),
      gemeindeschluessel: faker.location.countryCode(),
    },
    signatur: faker.lorem.lines(3),
  };
}

export function createPostfachSettingItem(): PostfachSettingsItem {
  return {
    name: SettingName.POSTFACH,
    settingBody: createPostfach(),
  };
}

export function createPostfachResource(): PostfachResource {
  return toResource(createPostfachSettingItem());
}

export function createSettingItemResource(): SettingItemResource {
  return toResource({
    name: faker.word.sample(),
    settingBody: {},
  });
}
