/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Postfach, PostfachResource, PostfachService } from '@admin-client/postfach-shared';
import { AbstractFormService, EMPTY_STRING, StateResource } from '@alfa-client/tech-shared';
import { inject, Injectable } from '@angular/core';
import { FormControl, UntypedFormGroup } from '@angular/forms';
import { isNil } from 'lodash-es';
import { Observable } from 'rxjs';

@Injectable()
export class PostfachFormService extends AbstractFormService {
  private postfachService: PostfachService = inject(PostfachService);

  public static readonly ASBSENDER_GROUP: string = 'absender';
  public static readonly NAME_FIELD: string = 'name';
  public static readonly ANSCHRIFT_FIELD: string = 'anschrift';
  public static readonly DIENST_FIELD: string = 'dienst';
  public static readonly MANDANT_FIELD: string = 'mandant';
  public static readonly GEMEINDESCHLUESSEL_FIELD: string = 'gemeindeschluessel';

  public static readonly SIGNATUR_FIELD: string = 'signatur';

  protected initForm(): UntypedFormGroup {
    return this.formBuilder.group({
      [PostfachFormService.ASBSENDER_GROUP]: this.formBuilder.group({
        [PostfachFormService.NAME_FIELD]: new FormControl(EMPTY_STRING),
        [PostfachFormService.ANSCHRIFT_FIELD]: new FormControl(EMPTY_STRING),
        [PostfachFormService.DIENST_FIELD]: new FormControl(EMPTY_STRING),
        [PostfachFormService.MANDANT_FIELD]: new FormControl(EMPTY_STRING),
        [PostfachFormService.GEMEINDESCHLUESSEL_FIELD]: new FormControl(EMPTY_STRING),
      }),
      [PostfachFormService.SIGNATUR_FIELD]: new FormControl(EMPTY_STRING),
    });
  }

  protected doSubmit(): Observable<StateResource<PostfachResource>> {
    const value: Postfach = this.getFormValue();
    if (this.shouldSkipAbsender(value)) {
      delete value.absender;
    }
    return this.postfachService.save(value);
  }

  private shouldSkipAbsender(postfach: Postfach): boolean {
    return isNil(this.source?.absender) && Object.values(postfach.absender).every((v) => isNil(v) || v.length === 0);
  }

  protected getPathPrefix(): string {
    return 'settingBody';
  }
}
