/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { PostfachResource } from '@admin-client/postfach-shared';
import { StateResource, createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { TestBed } from '@angular/core/testing';
import { singleCold } from 'libs/tech-shared/test/marbles';
import { Observable, of } from 'rxjs';
import { createPostfachResource, createSettingItemResource } from '../../../postfach-shared/src/test/postfach';
import { createSettingsListResource } from '../../test/settings';
import { SettingListResourceService } from './settings-resource.service';
import { SettingListResource } from './settings.model';
import { SettingsService } from './settings.service';

describe('SettingsService', () => {
  let service: SettingsService;
  let settingListResourceService: Mock<SettingListResourceService>;

  beforeEach(() => {
    settingListResourceService = mock(SettingListResourceService);

    TestBed.configureTestingModule({
      providers: [SettingsService, { provide: SettingListResourceService, useValue: settingListResourceService }],
    });

    service = TestBed.inject(SettingsService);
  });

  it('should create', () => {
    expect(service).toBeTruthy();
  });

  describe('get Postfach', () => {
    const postfachResource = createPostfachResource();
    const postfachStateResource: StateResource<PostfachResource> = createStateResource(postfachResource);
    const settingsListResource: StateResource<SettingListResource> = createStateResource(
      createSettingsListResource([postfachResource]),
    );

    beforeEach(() => {
      settingListResourceService.getList = jest.fn().mockReturnValue(of(settingsListResource));
    });

    it('should call resource service', () => {
      service.getPostfach();

      expect(settingListResourceService.getList).toHaveBeenCalled();
    });

    it('should return null for non postfach resource', () => {
      const emptySettingsListResource: StateResource<SettingListResource> = createStateResource(
        createSettingsListResource([createSettingItemResource()]),
      );

      settingListResourceService.getList = jest.fn().mockReturnValue(singleCold(emptySettingsListResource));

      const postfach: Observable<StateResource<PostfachResource>> = service.getPostfach();
      expect(postfach).toBeObservable(singleCold(createEmptyStateResource()));
    });

    it('should return item resource as postfach resource', () => {
      settingListResourceService.getList = jest.fn().mockReturnValue(singleCold(settingsListResource));

      const postfach: Observable<StateResource<PostfachResource>> = service.getPostfach();

      expect(postfach).toBeObservable(singleCold(postfachStateResource));
    });
  });
});
