/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { PostfachResource } from '@admin-client/postfach-shared';
import {
  createEmptyStateResource,
  createStateResource,
  getEmbeddedResources,
  isNotNil,
  StateResource,
} from '@alfa-client/tech-shared';
import { SettingListLinkRel } from './settings.linkrel';
import { SettingItemResource, SettingListResource, SettingName } from './settings.model';

export function getPostfachResource(settingsListResource: StateResource<SettingListResource>): StateResource<PostfachResource> {
  const entries: SettingItemResource[] = getEmbeddedResources(settingsListResource, SettingListLinkRel.LIST);
  const postfachSettingItemResource: SettingItemResource = entries.find(isPostfachSettingItem);
  return isNotNil(postfachSettingItemResource) ?
      createStateResource(postfachSettingItemResource as PostfachResource)
    : createEmptyStateResource();
}

function isPostfachSettingItem(item: SettingItemResource): boolean {
  return item.name === SettingName.POSTFACH;
}
