/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ROUTES } from '@admin-client/shared';
import { NavigationService } from '@alfa-client/navigation-shared';
import { existsAsHtmlElement, mock, Mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { getDataTestIdAttributeOf } from '../../../../../tech-shared/test/data-test';
import { StatistikContainerComponent } from './statistik-container.component';

describe('StatistikContainerComponent', () => {
  let component: StatistikContainerComponent;
  let fixture: ComponentFixture<StatistikContainerComponent>;

  const evaluateAdditionalFieldsTestId: string = getDataTestIdAttributeOf('weitere-felder-auswerten-button');

  let navigationService: Mock<NavigationService>;

  beforeEach(() => {
    navigationService = mock(NavigationService);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [StatistikContainerComponent],
      providers: [
        {
          provide: NavigationService,
          useValue: navigationService,
        },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(StatistikContainerComponent);
    component = fixture.componentInstance;

    fixture.detectChanges();
  });

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    describe('navigateToStatistikFieldsForm', () => {
      it('should call navigation service', () => {
        component.navigateToStatistikFieldsForm();

        expect(navigationService.navigate).toHaveBeenCalledWith(ROUTES.STATISTIK_NEU);
      });
    });
  });

  describe('template', () => {
    describe('weiter felder auswerten button', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, evaluateAdditionalFieldsTestId);
      });

      describe('output', () => {
        describe('clickEmitter', () => {
          it('should call handler', () => {
            component.navigateToStatistikFieldsForm = jest.fn();
            fixture.detectChanges();

            triggerEvent({
              fixture,
              elementSelector: evaluateAdditionalFieldsTestId,
              name: 'clickEmitter',
            });

            expect(component.navigateToStatistikFieldsForm).toHaveBeenCalled();
          });
        });
      });
    });
  });
});
