/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Injectable } from '@angular/core';
import { map, Observable } from 'rxjs';
import { KeycloakResourceService } from './keycloak.resource.service';
import { User } from './user.model';
import { UserRepository } from './user.repository.service';
import { sortUsersByLastName } from './user.util';

@Injectable({
  providedIn: 'root',
})
export class UserService extends KeycloakResourceService<User> {
  constructor(private userRepository: UserRepository) {
    super();
  }

  getItemsFromKeycloak(): Observable<User[]> {
    return this.userRepository.getUsers().pipe(map(sortUsersByLastName));
  }

  createInKeycloak(user: Partial<User>): Observable<User> {
    return this.userRepository.createInKeycloak(user);
  }

  saveInKeycloak(user: User): Observable<void> {
    throw new Error('Method not implemented.');
  }

  deleteInKeycloak(id: string): Observable<void> {
    throw new Error('Method not implemented.');
  }
}
