/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { User } from '@admin-client/user-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { AsyncPipe } from '@angular/common';
import { Component, inject } from '@angular/core';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { ButtonWithSpinnerComponent, CheckboxEditorComponent, TextEditorComponent } from '@ods/component';
import { Observable } from 'rxjs';
import { UserAddFormservice } from './user-add.formservice';

@Component({
  selector: 'admin-user-add-form',
  providers: [UserAddFormservice],
  templateUrl: './user-add-form.component.html',
  standalone: true,
  imports: [
    FormsModule,
    ReactiveFormsModule,
    TextEditorComponent,
    ButtonWithSpinnerComponent,
    CheckboxEditorComponent,
    AsyncPipe,
  ],
})
export class UserAddFormComponent {
  public readonly formService = inject(UserAddFormservice);

  submitStateResource$: Observable<StateResource<User>>;

  protected readonly UserAddFormService = UserAddFormservice;

  public submit(): void {
    if (!this.formService.form.invalid) {
      this.submitStateResource$ = this.formService.submit();
    }
  }
}
