/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ROUTES } from '@admin-client/shared';
import { ToUserNamePipe, User, UserService } from '@admin-client/user-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { CommonModule } from '@angular/common';
import { Component, inject, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { ListComponent, ListItemComponent, MailboxIconComponent, PersonIconComponent } from '@ods/system';
import { Observable } from 'rxjs';

@Component({
  selector: 'admin-users-roles',
  templateUrl: './users-roles.component.html',
  standalone: true,
  imports: [
    CommonModule,
    ButtonWithSpinnerComponent,
    ListComponent,
    ListItemComponent,
    MailboxIconComponent,
    PersonIconComponent,
    ToUserNamePipe,
  ],
})
export class UsersRolesComponent implements OnInit {
  private router = inject(Router);
  private userService = inject(UserService);

  public users$: Observable<StateResource<User[]>>;
  public readonly GROUPS_TO_DISPLAY: number = 3;

  ngOnInit() {
    this.users$ = this.userService.get();
  }

  public navigateToAddUser(): void {
    this.router.navigate([ROUTES.BENUTZER_UND_ROLLEN_NEU]);
  }

  getRoles(user: User): string[] {
    return Object.keys(user.clientRoles).reduce((acc: string[], client: string): string[] => {
      acc.push(...user.clientRoles[client]);
      return acc;
    }, []);
  }
}
