/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Bescheid } from '@alfa-client/bescheid-shared';
import { existsAsHtmlElement, getElementFromFixtureByType, Mock, mock, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { BescheidStatusTextComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { EMPTY, of } from 'rxjs';
import { createBescheid } from '../../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../../tech-shared/test/data-test';
import { BescheidFormService } from '../../../bescheid.formservice';
import { BescheidWizardAntragBescheidenSummaryComponent } from './bescheid-wizard-antrag-bescheiden-summary.component';

describe('BescheidWizardAntragBescheidenSummaryComponent', () => {
  let component: BescheidWizardAntragBescheidenSummaryComponent;
  let fixture: ComponentFixture<BescheidWizardAntragBescheidenSummaryComponent>;

  const bescheidStatusText: string = getDataTestIdOf('bescheid-status-text');

  let formService: Mock<BescheidFormService>;

  beforeEach(() => {
    formService = mock(BescheidFormService);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [BescheidWizardAntragBescheidenSummaryComponent, MockComponent(BescheidStatusTextComponent)],
      providers: [{ provide: BescheidFormService, useValue: formService }],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardAntragBescheidenSummaryComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('ods-bescheid-status-text', () => {
      function getElementComponent(): BescheidStatusTextComponent {
        return getElementFromFixtureByType(fixture, BescheidStatusTextComponent);
      }

      it('should subscribe to bescheid value form changes', () => {
        fixture.detectChanges();

        expect(formService.getBescheidFormValueChanges).toHaveBeenCalled();
      });

      it('should NOT show', () => {
        formService.getBescheidFormValueChanges.mockReturnValue(EMPTY);

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, bescheidStatusText);
      });

      it('should show', () => {
        formService.getBescheidFormValueChanges.mockReturnValue(of(createBescheid()));

        fixture.detectChanges();

        existsAsHtmlElement(fixture, bescheidStatusText);
      });

      describe('input', () => {
        it('should set bewilligt', () => {
          const bescheid: Bescheid = createBescheid();
          formService.getBescheidFormValueChanges.mockReturnValue(of(bescheid));

          fixture.detectChanges();

          expect(getElementComponent().bewilligt).toBe(bescheid.bewilligt);
        });

        it('should set dateText', () => {
          const bescheid: Bescheid = { ...createBescheid(), beschiedenAm: '2024-01-01' };
          formService.getBescheidFormValueChanges.mockReturnValue(of(bescheid));

          fixture.detectChanges();

          expect(getElementComponent().dateText).toBe('01.01.2024');
        });

        it('should set hasBescheidDraft', () => {
          const bescheid: Bescheid = createBescheid();
          formService.getBescheidFormValueChanges.mockReturnValue(of(bescheid));

          fixture.detectChanges();

          expect(getElementComponent().hasBescheidDraft).toBeFalsy();
        });
      });
    });
  });
});
