/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';

import { OutgoingMailErrorContainerComponent } from './outgoing-mail-error-container.component';
import { PostfachMailLinkRel, PostfachService } from '@alfa-client/postfach-shared';
import { mock } from '@alfa-client/test-utils';
import { OutgoingMailErrorComponent } from './outgoing-mail-error/outgoing-mail-error.component';
import { MockComponent } from 'ng-mocks';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import { createPostfachMailResource } from '../../../../../../../../postfach-shared/test/postfach';

describe('OutgoingMailErrorContainerComponent', () => {
  let component: OutgoingMailErrorContainerComponent;
  let fixture: ComponentFixture<OutgoingMailErrorContainerComponent>;

  const postfachService = mock(PostfachService);
  const mailError: string = '[data-test-id="outgoing-mail-error"]';

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        OutgoingMailErrorContainerComponent,
        MockComponent(OutgoingMailErrorComponent),
        HasLinkPipe,
      ],
      providers: [
        {
          provide: PostfachService,
          useValue: postfachService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(OutgoingMailErrorContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('resendMail', () => {
    it('should call postfach service', () => {
      component.resendMail();

      expect(postfachService.resendMail).toHaveBeenCalled();
    });
  });

  describe('outgoing mail error', () => {
    it('should show', () => {
      component.postfachMailResource = createPostfachMailResource([
        PostfachMailLinkRel.RESEND_POSTFACH_MAIL,
      ]);
      fixture.detectChanges();

      const element = fixture.nativeElement.querySelector(mailError);

      expect(element).toBeInstanceOf(HTMLElement);
    });

    it('should hide', () => {
      component.postfachMailResource = createPostfachMailResource();
      fixture.detectChanges();

      const element = fixture.nativeElement.querySelector(mailError);

      expect(element).not.toBeInstanceOf(HTMLElement);
    });
  });
});
