/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createAriaLabelForIconButton } from '@alfa-client/tech-shared';
import { getElementFromFixture } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatIcon } from '@angular/material/icon';
import { MatIconTestingModule } from '@angular/material/icon/testing';
import { TooltipDirective } from '@ods/system';
import { getDataTestClassOf } from 'libs/tech-shared/test/data-test';
import { MockComponent, MockDirective } from 'ng-mocks';
import { OzgcloudIconButtonPrimaryComponent } from './ozgcloud-icon-button-primary.component';

jest.mock('@alfa-client/tech-shared');
const createAriaLabelForIconButtonMock = createAriaLabelForIconButton as jest.Mock;

describe('IconButtonPrimaryWithSpinnerComponent', () => {
  let component: OzgcloudIconButtonPrimaryComponent;
  let fixture: ComponentFixture<OzgcloudIconButtonPrimaryComponent>;

  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [MatIconTestingModule],
      declarations: [OzgcloudIconButtonPrimaryComponent, MockComponent(MatIcon), MockDirective(TooltipDirective)],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(OzgcloudIconButtonPrimaryComponent);
    component = fixture.componentInstance;
    component.svgIcon = 'edit';

    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should create aria label', () => {
      component.ngOnInit();

      expect(createAriaLabelForIconButtonMock).toHaveBeenCalledWith(
        component.tooltip,
        component.svgIcon,
      );
    });

    it('should set aria label', () => {
      const ariaLabel = 'Eine Taste';
      createAriaLabelForIconButtonMock.mockReturnValue(ariaLabel);

      component.ngOnInit();

      expect(component.ariaLabel).toBe(ariaLabel);
    });
  });

  describe('onClick', () => {
    it('should emit event', () => {
      const element = getElementFromFixture(fixture, getDataTestClassOf('icon-button-primary'));
      const emitSpy = jest.spyOn(component.clickEmitter, 'emit');

      element.click();

      expect(emitSpy).toHaveBeenCalled();
    });
  });
});
