/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidService, DocumentResource } from '@alfa-client/bescheid-shared';
import { CommandResource } from '@alfa-client/command-shared';
import { hasStateResourceError, isNotNil, StateResource } from '@alfa-client/tech-shared';
import { Component, Input, OnInit } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { Observable } from 'rxjs';
import { BescheidenFormService } from '../../bescheiden.formservice';

@Component({
  selector: 'alfa-vorgang-detail-bescheiden-result-nachricht',
  templateUrl: './vorgang-detail-bescheiden-result-nachricht.component.html',
})
export class VorgangDetailBescheidenResultNachrichtComponent implements OnInit {
  @Input()
  set bescheidDocumentStateResource(stateResource: StateResource<DocumentResource>) {
    if (!stateResource.loading && !stateResource.error && isNotNil(stateResource.resource)) {
      if (isNotNil(this.form) && this.form.valid) {
        this.formService.patchNachricht(stateResource.resource);
      }
    }
  }

  @Input()
  set sendWithNachrichtCommandStateResource(stateResource: StateResource<CommandResource>) {
    this.resetFocus();
    if (isNotNil(stateResource) && hasStateResourceError(stateResource)) {
      if (this.formService.isBetreffInvalid()) {
        this.focusBetreff = true;
      } else if (this.formService.isNachrichtInvalid()) {
        this.focusNachricht = true;
      }
    }
  }

  resetFocus() {
    this.focusBetreff = false;
    this.focusNachricht = false;
  }

  empfaenger$: Observable<string>;
  form: FormGroup;

  public focusBetreff: boolean = false;
  public focusNachricht: boolean = false;

  readonly formServiceClass = BescheidenFormService;

  constructor(
    private readonly bescheidService: BescheidService,
    private readonly formService: BescheidenFormService,
  ) {}

  ngOnInit(): void {
    this.empfaenger$ = this.bescheidService.getEmpfaenger();
    this.form = this.formService.form;
  }
}
