/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidService } from '@alfa-client/bescheid-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { EventEmitter } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { BescheidenFormService } from '../../bescheiden.formservice';
import { VorgangDetailBescheidenStepButtonComponent } from './vorgang-detail-bescheiden-step-button/vorgang-detail-bescheiden-step-button.component';
import { VorgangDetailBescheidenStepButtonsComponent } from './vorgang-detail-bescheiden-step-buttons.component';

describe('VorgangDetailBescheidenStepButtonsComponent', () => {
  let component: VorgangDetailBescheidenStepButtonsComponent;
  let fixture: ComponentFixture<VorgangDetailBescheidenStepButtonsComponent>;

  const formService: Mock<BescheidenFormService> = mock(BescheidenFormService);
  const bescheidService: Mock<BescheidService> = mock(BescheidService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        VorgangDetailBescheidenStepButtonsComponent,
        MockComponent(VorgangDetailBescheidenStepButtonComponent),
      ],
      providers: [
        {
          provide: BescheidenFormService,
          useValue: formService,
        },
        {
          provide: BescheidService,
          useValue: bescheidService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangDetailBescheidenStepButtonsComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('changeActiveStep', () => {
    const step: number = 1;
    beforeEach(() => {
      component.activeStepChange = <any>mock(EventEmitter);
    });

    it('should emit step', () => {
      component.changeActiveStep(step);

      expect(component.activeStepChange.emit).toHaveBeenCalledWith(step);
    });

    it('should set active step in formservice', () => {
      component.changeActiveStep(step);

      expect(formService.setActiveStep).toHaveBeenCalledWith(step);
    });
  });
});
