/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { ChangeDetectorRef, Component, Input, OnChanges, QueryList, SimpleChanges, ViewChild, ViewChildren } from '@angular/core';
import { DropdownMenuComponent, DropdownMenuTextItemComponent } from '@ods/system';
import { has } from 'lodash-es';

@Component({
  selector: 'alfa-vorgang-detail-more-menu',
  templateUrl: './vorgang-detail-more-menu.component.html',
  styleUrls: ['./vorgang-detail-more-menu.component.scss'],
})
export class VorgangDetailMoreMenuComponent implements OnChanges {
  @Input() vorgangWithEingang: VorgangWithEingangResource;

  @ViewChild(DropdownMenuComponent) menu: DropdownMenuComponent;
  @ViewChildren(DropdownMenuTextItemComponent) menuItems!: QueryList<DropdownMenuTextItemComponent>;

  public buttonEnabled: boolean = false;

  public readonly vorgangWithEingangLinkRel = VorgangWithEingangLinkRel;

  constructor(private changeDetectorRef: ChangeDetectorRef) {}

  ngOnChanges(changes: SimpleChanges): void {
    if (has(changes, 'vorgangWithEingang')) {
      this.vorgangWithEingangChanged();
    }
  }

  public vorgangWithEingangChanged(): void {
    this.changeDetectorRef.detectChanges();
    this.buttonEnabled = this.hasMenuItems();
  }

  public hasMenuItems(): boolean {
    return this.menuItems?.length > 0;
  }

  public closeMenu(): void {
    this.menu.closeMenu();
  }
}
