/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Component, OnInit } from '@angular/core';
import { ApiRootResource, ApiRootService } from '@alfa-client/api-root-shared';
import { StateResource } from '@alfa-client/tech-shared';
import {
  VorgangListResource,
  VorgangListService,
  VorgangResource,
} from '@alfa-client/vorgang-shared';
import { Observable } from 'rxjs';

@Component({
  selector: 'alfa-vorgang-list-container',
  templateUrl: './vorgang-list-container.component.html',
  styleUrls: ['./vorgang-list-container.component.scss'],
})
export class VorgangListContainerComponent implements OnInit {
  public apiRootStateResource$: Observable<StateResource<ApiRootResource>>;

  public vorgangListPageResource$: Observable<StateResource<VorgangListResource>>;
  public vorgaenge$: Observable<VorgangResource[]>;
  public searchString$: Observable<string>;

  constructor(
    private vorgangListService: VorgangListService,
    private apiRootService: ApiRootService,
  ) {}

  ngOnInit(): void {
    this.apiRootStateResource$ = this.apiRootService.getApiRoot();

    this.vorgaenge$ = this.vorgangListService.getVorgaenge();
    this.vorgangListPageResource$ = this.vorgangListService.getVorgangList();
    this.searchString$ = this.vorgangListService.getSearchString();
  }

  loadNextPage(): void {
    this.vorgangListService.loadNextPage();
  }
}
