/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Mock, mock } from '@alfa-client/test-utils';
import {
  ExterneFachstelleResource,
  ExterneFachstelleService,
  ZUSTAENDIGE_STELLE_SERVICE,
} from '@alfa-client/zustaendige-stelle-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormControl } from '@angular/forms';
import { getUrl } from '@ngxp/rest';
import { ExternalUnitIconComponent } from '@ods/system';
import { createExterneFachstelleResource } from 'libs/zustaendige-stelle-shared/test/externe-fachstelle';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { EditZustaendigeStelleButtonComponent } from '../edit-zustaendige-stelle-button/edit-zustaendige-stelle-button.component';
import { ZustaendigeStelleButtonComponent } from '../zustaendige-stelle-button/zustaendige-stelle-button.component';
import { ZustaendigeStelleHeaderComponent } from '../zustaendige-stelle-header/zustaendige-stelle-header.component';
import { SearchExterneFachstelleContainerComponent } from './search-externe-fachstelle-container.component';

describe('SearchExterneFachstelleContainerComponent', () => {
  let component: SearchExterneFachstelleContainerComponent;
  let fixture: ComponentFixture<SearchExterneFachstelleContainerComponent>;

  const externeFachstelleResource: ExterneFachstelleResource = createExterneFachstelleResource();

  let externeFachstelleService: Mock<ExterneFachstelleService>;

  beforeEach(async () => {
    externeFachstelleService = {
      ...mock(ExterneFachstelleService),
      getSelectedResult: jest.fn().mockReturnValue(of(createExterneFachstelleResource())),
    };
    TestBed.overrideComponent(SearchExterneFachstelleContainerComponent, {
      set: {
        providers: [
          {
            provide: ZUSTAENDIGE_STELLE_SERVICE,
            useValue: externeFachstelleService,
          },
        ],
      },
    });
    await TestBed.configureTestingModule({
      declarations: [
        SearchExterneFachstelleContainerComponent,
        MockComponent(EditZustaendigeStelleButtonComponent),
        MockComponent(ZustaendigeStelleButtonComponent),
        MockComponent(ZustaendigeStelleHeaderComponent),
        MockComponent(ExternalUnitIconComponent),
      ],
      providers: [
        {
          provide: ExterneFachstelleService,
          useValue: externeFachstelleService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(SearchExterneFachstelleContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInt', () => {
    beforeEach(() => {
      component.getSelectedResult = jest.fn().mockReturnValue(of(externeFachstelleResource));
    });

    it('should call getSelectedResult', () => {
      component.ngOnInit();

      expect(component.getSelectedResult).toHaveBeenCalled();
    });

    it('should set externeFachstelleResource', (done) => {
      component.ngOnInit();

      component.externeFachstelleResource$.subscribe((externeFachstelleResource: ExterneFachstelleResource) => {
        expect(externeFachstelleResource).toBe(externeFachstelleResource);
        done();
      });
    });
  });

  describe('ngOnDestroy', () => {
    it('should clear selected result', () => {
      component.ngOnDestroy();

      expect(externeFachstelleService.clearSelectedResult).toHaveBeenCalled();
    });
  });

  describe('get selected result', () => {
    const externeFachstelleResource: ExterneFachstelleResource = createExterneFachstelleResource();

    beforeEach(() => {
      externeFachstelleService.getSelectedResult.mockReturnValue(of(externeFachstelleResource));
    });

    it('should call service', () => {
      component.getSelectedResult().subscribe();

      expect(externeFachstelleService.getSelectedResult).toHaveBeenCalled();
    });

    it('should call handleResult', () => {
      component.handleResult = jest.fn();

      component.getSelectedResult().subscribe();

      expect(component.handleResult).toHaveBeenCalledWith(externeFachstelleResource);
    });

    it('should return value', (done) => {
      component.handleResult = jest.fn();

      component.getSelectedResult().subscribe((result) => {
        expect(result).toBe(externeFachstelleResource);
        done();
      });
    });
  });

  describe('handle result', () => {
    beforeEach(() => {
      component.fieldControl = new FormControl();
    });

    it('should patch fieldControl with resource uri', () => {
      const fieldControlPatchSpy: jest.SpyInstance = (component.fieldControl.patchValue = jest.fn());

      component.handleResult(externeFachstelleResource);

      expect(fieldControlPatchSpy).toHaveBeenCalledWith(getUrl(externeFachstelleResource));
    });

    it('should not patch fieldControl if externeFachstelle resource is null', () => {
      const fieldControlPatchSpy: jest.SpyInstance = (component.fieldControl.patchValue = jest.fn());

      component.handleResult(null);

      expect(fieldControlPatchSpy).not.toHaveBeenCalled();
    });
  });
});
